@@ -12,6 +12,7 @@ from collections import namedtuple
 import urlparse
 
 SearchEngine = namedtuple('SearchEngine', 'name domain keywords')
+MailProvider = namedtuple('MailProvider', 'name')
 
 import engines
 
@@ -27,4 +28,7 @@ def who(url):
         keywords = query.get(result.param, [''])[0].split(' ') or None
         return SearchEngine(result.name, domain, keywords)
 
+    elif isinstance(result, engines.MailDef):
+        return MailProvider(result.name)
+
     return result
